using System.ComponentModel;

namespace GridPoc.DataTypes
{
	internal class Measurement: INotifyPropertyChanged
	{
		#region Private fields

		private string _name;
		private decimal _value1;
		private decimal _value2;
		private decimal _value3;
		private decimal _value4;
		private bool _isManual;

		#endregion

		#region Constructors

		public Measurement() : this(string.Empty, 0, 0, 0, 0) {}

		public Measurement(string name, decimal value1, decimal value2, decimal value3, decimal value4)
		{
			_name = name;
			_value1 = value1;
			_value2 = value2;
			_value3 = value3;
			_value4 = value4;
		}

		#endregion

		#region Private methods

		private void InvokePropertyChanged(string propertyName)
		{
			PropertyChangedEventHandler changed = PropertyChanged;
			if (changed != null) changed(this, new PropertyChangedEventArgs(propertyName));
		}

		#endregion

		#region Public fields

		public event PropertyChangedEventHandler PropertyChanged;

		public string Name
		{
			get { return _name; }
			set
			{
				_name = value;
				InvokePropertyChanged("Name");
			}
		}

		[Grid(Alias = "Waarde 1")]
		public decimal Value1
		{
			get { return _value1; }
			set
			{
				_value1 = value;
				InvokePropertyChanged("Value1");
			}
		}

    //[GridDependantBGColor(NumericConditionalOperators.GreaterThan, ConditionValue = 100.0m)]
		public decimal Value2
		{
			get { return _value2; }
			set
			{
				_value2 = value;
				InvokePropertyChanged("Value2");
			}
		}

		public decimal Value3
		{
			get { return _value3; }
			set
			{
				_value3 = value;
				InvokePropertyChanged("Value3");
			}
		}

		public decimal Value4
		{
			get { return _value4; }
			set
			{
				_value4 = value;
				InvokePropertyChanged("Value4");
			}
		}

		public bool IsManual
		{
			get { return _isManual; }
			set
			{
				_isManual = value;
				InvokePropertyChanged("IsManual");
			}
		}

		#endregion

		#region Public methods

		public bool Equals(Measurement other)
		{
			if (ReferenceEquals(null, other)) return false;
			if (ReferenceEquals(this, other)) return true;
			return Equals(other._name, _name) && other._value1 == _value1 && other._value2 == _value2 && other._value3 == _value3 && other._value4 == _value4;
		}

		public override bool Equals(object obj)
		{
			if (ReferenceEquals(null, obj)) return false;
			if (ReferenceEquals(this, obj)) return true;
			if (obj.GetType() !=
			    typeof (Measurement)) return false;
			return Equals((Measurement)obj);
		}

		public override int GetHashCode()
		{
			unchecked
			{
				int result = (_name != null
				              	? _name.GetHashCode()
				              	: 0);
				result = (result * 397) ^ _value1.GetHashCode();
				result = (result * 397) ^ _value2.GetHashCode();
				result = (result * 397) ^ _value3.GetHashCode();
				result = (result * 397) ^ _value4.GetHashCode();
				return result;
			}
		}

		#endregion
	}
}