using System.ComponentModel;
using System.Linq;

namespace GridPoc.DataTypes
{
	internal class Pool: INotifyPropertyChanged
	{
		#region Private fields

		private string _name;
		private readonly BindingList<Segment> _segments;
		private bool _isManual;

		#endregion

		#region Constructors

		public Pool() : this(string.Empty, new BindingList<Segment>()) { }

		public Pool(string name, BindingList<Segment> segments)
		{
			_name = name;
			_segments = segments;
		}
		#endregion

		#region Private methods

		private void updateUnderlying(bool value)
		{
			foreach (var segment in Segments)
			{
				segment.IsManual = value;
			}
		}

		private void InvokePropertyChanged(string propertyName)
		{
			PropertyChangedEventHandler changed = PropertyChanged;
			if (changed != null) changed(this, new PropertyChangedEventArgs(propertyName));
		}

		#endregion

		#region Public fields

		public event PropertyChangedEventHandler PropertyChanged;

		public BindingList<Segment> Segments
		{
			get { return _segments; }
		}

		[Grid(Editable=false)]
		public string Name
		{
			get { return _name; }
			set
			{
				_name = value;
				InvokePropertyChanged("Name");
			}
		}

    
		public decimal Total1
		{
			get { return _segments.Sum(s => s.Total1); }
		}

		public decimal Total2
		{
			get { return _segments.Sum(s => s.Total2); }
		}

		public decimal Total3
		{
			get { return _segments.Sum(s => s.Total3); }
		}

		public decimal Total4
		{
			get { return _segments.Sum(s => s.Total4); }
		}

		public bool IsManual
		{
			get { return _isManual; }
			set
			{
				_isManual = value;
				InvokePropertyChanged("IsManual");
				updateUnderlying(value);
			}
		}

		#endregion

		#region Public methods

		public bool Equals(Pool other)
		{
			if (ReferenceEquals(null, other)) return false;
			if (ReferenceEquals(this, other)) return true;
			return Equals(other._name, _name) && Equals(other._segments, _segments);
		}

		public override bool Equals(object obj)
		{
			if (ReferenceEquals(null, obj)) return false;
			if (ReferenceEquals(this, obj)) return true;
			if (obj.GetType() != typeof (Pool)) return false;
			return Equals((Pool)obj);
		}

		public override int GetHashCode()
		{
			unchecked
			{
				return ((_name != null ? _name.GetHashCode() : 0) * 397) ^ (_segments != null ? _segments.GetHashCode() : 0);
			}
		}

		#endregion
	}
}