using System.ComponentModel;
using System.Linq;

namespace GridPoc.DataTypes
{
	internal class Segment: INotifyPropertyChanged
	{
		#region Private fields

		private string _name;
		private readonly BindingList<Measurement> _measurements;
		private bool _isManual;

		#endregion

		#region Constructors

		public Segment(): this(string.Empty, new BindingList<Measurement>()) {}

		public Segment(string name, BindingList<Measurement> measurements)
		{
			_name = name;
			_measurements = measurements;
		}

		#endregion

		#region Private methods
    
		private void updateUnderlying(bool value)
		{
			foreach (var measurement in Measurements)
			{
				measurement.IsManual = value;
			}
		}

		private void InvokePropertyChanged(string propertyName)
		{
			PropertyChangedEventHandler changed = PropertyChanged;
			if (changed != null) changed(this, new PropertyChangedEventArgs(propertyName));
		}

		#endregion

		#region Public fields

		public event PropertyChangedEventHandler PropertyChanged;

		public BindingList<Measurement> Measurements
		{
			get { return _measurements; }
		}
		public string Name
		{
			get { return _name; }
			set
			{
				_name = value;
				InvokePropertyChanged("Name");
			}
		}

		public decimal Total1
		{
			get { return _measurements.Sum(m => m.Value1); }
		}

		public decimal Total2
		{
			get { return _measurements.Sum(m => m.Value2); }
		}

		public decimal Total3
		{
			get { return _measurements.Sum(m => m.Value3); }
		}

		public decimal Total4
		{
			get { return _measurements.Sum(m => m.Value4); }
		}

		public bool IsManual
		{
			get { return _isManual; }
			set
			{
				_isManual = value;
				InvokePropertyChanged("IsManual");
				updateUnderlying(value);
			}
		}

		#endregion

		#region Public methods

		public bool Equals(Segment other)
		{
			if (ReferenceEquals(null, other)) return false;
			if (ReferenceEquals(this, other)) return true;
			return Equals(other._name, _name) && Equals(other._measurements, _measurements);
		}

		public override bool Equals(object obj)
		{
			if (ReferenceEquals(null, obj)) return false;
			if (ReferenceEquals(this, obj)) return true;
			if (obj.GetType() != typeof (Segment)) return false;
			return Equals((Segment)obj);
		}

		public override int GetHashCode()
		{
			unchecked
			{
				return ((_name != null ? _name.GetHashCode() : 0) * 397) ^ (_measurements != null ? _measurements.GetHashCode() : 0);
			}
		}

		#endregion
	}
}