using System;
using System.ComponentModel;

using GridPoc.DataTypes;

namespace GridPoc
{
  internal static class DummyDataBuilder
  {
    public static BindingList<Pool> BuildDummyData()
    {
      var result = new BindingList<Pool>();

      result.Add(new Pool("Alfa", buildSegments("Alpha")));
      result.Add(new Pool("Beta", buildSegments("Bravo")));
      result.Add(new Pool("Gamma", buildSegments("Charlie")));
      result.Add(new Pool("Delta", buildSegments("Delta")));
      result.Add(new Pool("Epsilon", buildSegments("Echo")));

      return result;
    }

    public static BindingList<RichMeasurement> FlattenData(BindingList<Pool> pools)
    {
      var result = new BindingList<RichMeasurement>();

      foreach (Pool pool in pools)
      {
        foreach (Segment segment in pool.Segments)
        {
          foreach (Measurement measurement in segment.Measurements)
          {
            result.Add(new RichMeasurement(measurement.Value1,
                                           measurement.Value2,
                                           measurement.Value3,
                                           measurement.Value4,
                                           pool.Name,
                                           segment.Name,
                                           measurement.Name));
          }
        }
      }

      return result;
    }

    private static BindingList<Segment> buildSegments(string name)
    {
      var result = new BindingList<Segment>();
      var rand = new Random(name.GetHashCode());
      int segmentCount = rand.Next() % 5;

      for (int i = -1; i < segmentCount; i++)
      {
        string seedName = name + (i + 1);
        result.Add(new Segment(seedName, buildMeasurements(seedName)));
      }

      return result;
    }

    private static BindingList<Measurement> buildMeasurements(string name)
    {
      const int resultCount = 10;
      var result = new BindingList<Measurement>();
      int hash = name.GetHashCode();
      var rand = new Random(hash);
      var randFullValues = new byte[resultCount];
      var randDecvalues = new byte[resultCount];
      var randValues = new decimal[resultCount];

      rand.NextBytes(randFullValues);
      rand.NextBytes(randDecvalues);

      for (int i = 0; i < randDecvalues.Length; i++)
      {
        randValues[i] = randDecvalues[i] + (randDecvalues[i] / 100);
        result.Add(new Measurement(name + i,
                                   randValues[i],
                                   (int)randValues[i] ^ hash,
                                   randValues[i] / hash,
                                   randValues[i] * hash));
      }

      return result;
    }
  }
}