﻿using System;
using System.ComponentModel;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;
using GridPoc.DataTypes;

using Infragistics.Win.UltraWinGrid;

namespace GridPoc
{
	public partial class GridSample : Form
	{
    private string order = string.Empty;
    private UltraGridRow row = null;

    public GridSample()
		{
			InitializeComponent();
		}

		private void HierarchyGrid_Load(object sender, EventArgs e)
		{
			BindingList<Pool> data = DummyDataBuilder.BuildDummyData();
			TestGridMain.DataSource = data;
			TestGridMain.DataBind();
      TestGridMain.DisplayLayout.RowConnectorStyle = RowConnectorStyle.None;
      InsertStupidRows();
		}

	  private void InsertStupidRows()
	  {
      order += "INS ";
      var newRow = TestGridMain.DisplayLayout.Bands[1].AddNew();
      newRow.Cells["Name"].SetValue("Bla bla bla", false);
      newRow.Appearance.BackColor = Color.Pink;
      TestGridMain.Rows.Move(row, 2);
	  }

	  private void TestGridMain_ClickCell(object sender, ClickCellEventArgs e)
		{ 
		}

		private void TestGridMain_InitializeLayout(object sender, InitializeLayoutEventArgs e)
		{
      order += "INIT ";

		  applyGridSettings(typeof(Pool), e.Layout.Bands[0]);
      applyGridSettings(typeof(Segment), e.Layout.Bands[1]);
      applyGridSettings(typeof(Measurement), e.Layout.Bands[2]);
		}

	  private static void applyGridSettings(Type poolType, UltraGridBand band)
	  {
	    foreach (PropertyInfo prop in poolType.GetProperties())
	    {
	      foreach (Attribute attrib in prop.GetCustomAttributes(true))
	      {
	        var gridAttrib = attrib as GridAttribute;

	        if (gridAttrib == null) continue;
	        if (gridAttrib.Editable == false)
	        {
            band.Columns[prop.Name].CellActivation = Activation.ActivateOnly;
	        }
	        if (!string.IsNullOrEmpty(gridAttrib.Alias))
	        {
            band.Columns[prop.Name].Header.Caption = gridAttrib.Alias;
	        }
	      }
	    }
	  }

	  private void TestGridMain_CellChange(object sender, CellEventArgs e)
		{
			if (e.Cell.Column == TestGridMain.DisplayLayout.Bands[0].Columns["IsManual"] ||
					e.Cell.Column == TestGridMain.DisplayLayout.Bands[1].Columns["IsManual"])
			{
				e.Cell.SetValue(!(bool)e.Cell.Value, false);
			}
		}

    private void button1_Click(object sender, EventArgs e)
    {
      if (row == null)
      {
        row = TestGridMain.DisplayLayout.Bands[2].AddNew();
        var nameCell = row.Cells["Name"];
        var rowLook = row.Appearance;

        nameCell.SetValue("Insert by button", false);
        row.Activation = Activation.Disabled;
        rowLook.BackColor = Color.Transparent;
        rowLook.BackColorDisabled = Color.Transparent;
        rowLook.BorderColor = Color.Transparent;
        rowLook.ForeColorDisabled = Color.Transparent;
        nameCell.Appearance.ForeColorDisabled = Color.Black;
        row.Cells["IsManual"].Appearance.AlphaLevel = 1;
        TestGridMain.Rows.Move(row, 5);
      }
      else
      {
        var currentIndex = row.Index;
        var targetIndex = currentIndex - 2;
        row.Cells["Name"].SetValue("Moved from " + currentIndex + " to " + targetIndex, false);
        TestGridMain.Rows.Move(row, targetIndex);
      }
    }
  }
}
